@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '0.95'; # VERSION
+our $VERSION = '0.96'; # VERSION
 
 
 use strict;
@@ -12,12 +12,26 @@ use File::Path qw/mkpath/;
 use File::Temp;
 use Clustericious::RouteBuilder;
 use Data::Dumper;
-use Filesys::Df qw/df/;
+use if $^O ne 'MSWin32', 'Filesys::Df' => qw/df/;
 use List::Util qw/shuffle/;
 use List::MoreUtils qw/uniq/;
 use Digest::file qw/digest_file_hex/;
 use File::Basename qw/basename/;
 
+BEGIN {
+  if($^O eq 'MSWin32')
+  {
+    # Filesys::Df is not available for MSWin32,
+    # so we use Filesys::DfPortable on that platform
+    require Filesys::DfPortable;
+    *df = sub {
+      my $df = Filesys::DfPortable::dfportable(@_);
+      $df->{used} = $df->{bused};
+      $df;
+    };
+  }
+}
+
 
 get '/' => sub { shift->render_text("welcome to Yars") } => 'index';
 
@@ -606,7 +620,7 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 0.95
+version 0.96
 
 =head1 ROUTES
 
